import React, { useContext } from 'react';
import { useLocation, matchPath } from 'react-router-dom';
import { GamesContext } from '../../context/games';

import { Color, Player, Board } from '../../components/Checkers';
import './GameBoard.css';

export default function GameBoard({ username, onStoneClick, onStoneMove }) {
  const games = useContext(GamesContext);
  const { pathname } = useLocation();

  const game = (() => {
    if (matchPath('/games/new', pathname))
      return games.newGame;

    if (matchPath('/games/proposal', pathname))
      return games.findGame({ uuid: games.proposal.selectedUUID });

    if (matchPath('/games/active', pathname))
      return games.findGame({ uuid: games.active.selectedUUID });

    if (matchPath('/games/archive', pathname))
      return games.findGame({ uuid: games.archive.selectedUUID });

    return {};
  })(); // <<-- Execute

  const opponentColor = Color.opposite(game?.myColor);
  const [opponentName, myName] = game?.opponentName ? [game.opponentName, username] : ['', ''];

  return (
    <div className='GameBoard'>
      <Player color={opponentColor || Color.black} name={opponentName} />
      <Board game={game} onStoneClick={onStoneClick} onStoneMove={onStoneMove} />
      <Player color={game?.myColor || Color.white} name={myName} />
    </div>
  )
}